@@ -1,17 +1,8 @@
-from .model_loader import (
-    load_model,
-    unload_model,
-)
-
-from .models_db import (
-    get_model_info_from_db,
-    get_models_db,
-)
-
 from .model_downloader import (
     download_model,
     download_models,
     resolve_downloaded_model_path,
 )
-
+from .model_loader import load_model, unload_model
+from .models_db import get_model_info_from_db, get_models_db
 from .scan_models import scan_model
