@@ -126,6 +126,12 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
 
     from .convert_from_ckpt import download_from_original_stable_diffusion_ckpt
 
+    from .optimizations import optimized_get_attention_scores
+
+    from diffusers.models.attention_processor import Attention
+
+    Attention.get_attention_scores = optimized_get_attention_scores
+
     log.info("loading on diffusers")
 
     log.info(f"using config: {config_file_path}")
@@ -154,6 +160,8 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
     save_tensor_file(default_pipe.vae.state_dict(), os.path.join(tempfile.gettempdir(), "sd-base-vae.safetensors"))
 
     if context.vram_usage_level == "low" and context.device != "mps":
+        if context.half_precision:
+            default_pipe = default_pipe.to("cpu", torch.float16, silence_dtype_warnings=True)
         default_pipe.enable_sequential_cpu_offload()
     else:
         if context.half_precision:
@@ -162,7 +170,7 @@ def load_diffusers_model(context: Context, model_path, config_file_path):
             default_pipe = default_pipe.to(context.device)
 
     if context.vram_usage_level != "high":
-        default_pipe.enable_attention_slicing()
+        default_pipe.enable_attention_slicing(1)
 
     try:
         import xformers
