@@ -1,5 +1,6 @@
 import numpy as np
 import torch
+from diffusers import StableDiffusionImg2ImgPipeline
 from einops import rearrange, repeat
 from PIL import Image, ImageOps
 
@@ -95,6 +96,9 @@ def diffusers_latent_samples_to_images(context: Context, samples):
     samples, model = samples
     samples = model.decode_latents(samples)
 
+    if isinstance(model, StableDiffusionImg2ImgPipeline):
+        return model.image_processor.postprocess(samples, output_type="pil")
+
     return model.numpy_to_pil(samples)
 
 
